@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 1999, 2018 Tanuki Software, Ltd.
+ * Copyright (c) 1999, 2019 Tanuki Software, Ltd.
  * http://www.tanukisoftware.com
  * All rights reserved.
  *
@@ -1151,6 +1151,26 @@ int _tstat(const wchar_t* filename, struct stat *buf) {
     return size;
 }
 
+int _tchown(const TCHAR *path, uid_t owner, gid_t group) {
+    char* cPath;
+    int r;
+    size_t size;
+
+    size = wcstombs(NULL, path, 0);
+    if (size == (size_t)-1) {
+        return -1;
+    }
+
+    cPath = malloc(size + 1);
+    if (cPath) {
+        wcstombs(cPath, path, size + 1);
+        r = chown(cPath, owner, group);
+        free(cPath);
+        return r;
+    }
+    return -1;
+}
+
 /**
  * Expands symlinks and resolves /./, /../ and extra '/' characters to produce a
  *  canonicalized absolute pathname.
